summaryrefslogtreecommitdiff
path: root/sc
diff options
context:
space:
mode:
authorEike Rathke <erack@redhat.com>2015-06-11 18:45:10 +0200
committerEike Rathke <erack@redhat.com>2015-06-11 18:51:13 +0200
commit6d7dcb81a25bb8896adad352a9e7151a41e18245 (patch)
treeb3a3a171f2b85f32298881fb5f6b63aa65b515bd /sc
parent47f002cbbf9593ab0097e178732e51b365b42732 (diff)
recompile TableRef formulas only after position was updated, tdf#91842
Change-Id: Ibdcfdd6175e6ccb8aded02d59b1b21e92a0fc120
Diffstat (limited to 'sc')
-rw-r--r--sc/source/core/data/formulacell.cxx6
1 files changed, 4 insertions, 2 deletions
diff --git a/sc/source/core/data/formulacell.cxx b/sc/source/core/data/formulacell.cxx
index 6352dce6c81d..4af29d6d1dcd 100644
--- a/sc/source/core/data/formulacell.cxx
+++ b/sc/source/core/data/formulacell.cxx
@@ -887,8 +887,10 @@ ScFormulaCell::ScFormulaCell( const ScFormulaCell& rCell, ScDocument& rDoc, cons
if ( !bCompileLater && bClipMode )
{
// Merging ranges needs the actual positions after UpdateReference.
- // ColRowNames need new lookup after positions are adjusted.
- bCompileLater = pCode->HasOpCode( ocRange) || pCode->HasOpCode( ocColRowName);
+ // ColRowNames and TableRefs need new lookup after positions are
+ // adjusted.
+ bCompileLater = pCode->HasOpCode( ocRange) || pCode->HasOpCode( ocColRowName) ||
+ pCode->HasOpCode( ocTableRef);
}
if ( !bCompileLater )
{